[prev in list] [next in list] [prev in thread] [next in thread] 

List:       subversion-cvs
Subject:    svn commit: r20905 - trunk/subversion/mod_dav_svn
From:       maxb () tigris ! org
Date:       2006-07-30 11:29:16
Message-ID: 20060730112916.2ED4D34C09F () svn ! collab ! net
[Download RAW message or body]

Author: maxb
Date: Sun Jul 30 04:29:16 2006
New Revision: 20905

Modified:
   trunk/subversion/mod_dav_svn/dav_svn.h

Log:
Ooops, omitted this file from the previous commit.

* subversion/mod_dav_svn/dav_svn.h: Update authz-related symbols to use
    double-underscore policy.


Modified: trunk/subversion/mod_dav_svn/dav_svn.h
URL: http://svn.collab.net/viewvc/svn/trunk/subversion/mod_dav_svn/dav_svn.h?pathrev=20905&r1=20904&r2=20905
 ==============================================================================
--- trunk/subversion/mod_dav_svn/dav_svn.h	(original)
+++ trunk/subversion/mod_dav_svn/dav_svn.h	Sun Jul 30 04:29:16 2006
@@ -619,7 +619,7 @@
                                    apr_pool_t *pool);
 
 
 /* A baton needed by dav_svn_authz_read(). */
 typedef struct 
 {
   /* The original request, needed to generate a subrequest. */
@@ -628,7 +628,7 @@
   /* We need this to construct a URI based on a repository abs path. */
   const dav_svn_repos *repos;
 
-} dav_svn_authz_read_baton;
+} dav_svn__authz_read_baton;
 
 
 /* Convert incoming RESOURCE and revision REV into a version-resource URI and
@@ -639,14 +639,14 @@
    Use POOL for any temporary allocation.
 */
 svn_boolean_t
-dav_svn_allow_read(const dav_resource *resource,
+dav_svn__allow_read(const dav_resource *resource,
                    svn_revnum_t rev,
                    apr_pool_t *pool);
 
 /* If authz is enabled in the specified BATON, return a read authorization
    function. Otherwise, return NULL. */
 svn_repos_authz_func_t
-dav_svn_authz_read_func(dav_svn_authz_read_baton *baton);
+dav_svn__authz_read_func(dav_svn__authz_read_baton *baton);
 
 /* Every provider needs to define an opaque locktoken type. */
 struct dav_locktoken

---------------------------------------------------------------------
@@ -619,7 +619,7 @@
 
 
-/* A baton needed by dav_svn_authz_read(). */
+/* A baton needed by dav_svn__authz_read_func(). */
 typedef struct 
 {
To unsubscribe, e-mail: svn-unsubscribe@subversion.tigris.org
For additional commands, e-mail: svn-help@subversion.tigris.org


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic